<?php

return array(
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Žádné',
    'Edit' => 'Editovat',
    'Remove' => 'Odstranit',
    'Yes' => 'Ano',
    'No' => 'Ne',
    'cancel' => 'Zrušit',
    'or' => 'nebo',
    'Yellow' => 'Žlutá',
    'Blue' => 'Modrá',
    'Green' => 'Zelená',
    'Purple' => 'Fialová',
    'Red' => 'Červená',
    'Orange' => 'Oranžová',
    'Grey' => 'Šedá',
    'Brown' => 'Hnědá',
    'Deep Orange' => 'Tmavě oranžová',
    'Dark Grey' => 'Tmavě šedá',
    'Pink' => 'Růžová',
    'Teal' => 'Modrozelená',
    'Cyan' => 'Tyrkysová',
    'Lime' => 'Limetková',
    'Light Green' => 'Světle zelená',
    'Amber' => 'Jantarová',
    'Save' => 'Uložit',
    'Login' => 'Přihlásit se',
    'Official website:' => 'Oficiální stránky:',
    'Unassigned' => 'Nepřiřazeno',
    'View this task' => 'Zobrazit úkol',
    'Remove user' => 'Odebrat uživatele',
    'Do you really want to remove this user: "%s"?' => 'Opravdu chcete odebrat uživatele: "%s"?',
    'All users' => 'Všichni uživatelé',
    'Username' => 'Uživatelské jméno',
    'Password' => 'Heslo',
    'Administrator' => 'Administrátor',
    'Sign in' => 'Přihlásit',
    'Users' => 'Uživatelé',
    'Forbidden' => 'Zakázáno',
    'Access Forbidden' => 'Přístup zakázán',
    'Edit user' => 'Upravit uživatele',
    'Logout' => 'Odhlásit',
    'Bad username or password' => 'Chybné uživatelské jméno nebo heslo',
    'Edit project' => 'Editovat projekt',
    'Name' => 'Jméno',
    'Projects' => 'Projekty',
    'No project' => 'Žádný projekt',
    'Project' => 'Projekt',
    'Status' => 'Stav',
    'Tasks' => 'Úkoly',
    'Board' => 'Nástěnka',
    'Actions' => 'Akce',
    'Inactive' => 'Neaktivní',
    'Active' => 'Aktivní',
    'Unable to update this board.' => 'Nástěnku není možné aktualizovat',
    'Disable' => 'Zakázat',
    'Enable' => 'Povolit',
    'New project' => 'Nový projekt',
    'Do you really want to remove this project: "%s"?' => 'Opravdu chcete odstranit projekt: "%s"?',
    'Remove project' => 'Odstranit projekt',
    'Edit the board for "%s"' => 'Editace nástěnky pro  "%s" ',
    'Add a new column' => 'Přidat nový sloupec',
    'Title' => 'Název',
    'Assigned to %s' => 'Přiřazeno uživateli: %s',
    'Remove a column' => 'Odstranit sloupec',
    'Unable to remove this column.' => 'Tento sloupec nelze odstranit',
    'Do you really want to remove this column: "%s"?' => 'Opravdu chcete odstranit tento sloupec: "%s"?',
    'Settings' => 'Nastavení',
    'Application settings' => 'Nastavení aplikace',
    'Language' => 'Čeština',
    'Webhook token:' => 'Webhook token:',
    'API token:' => 'API token:',
    'Database size:' => 'Velikost databáze:',
    'Download the database' => 'Stáhnout databázi',
    'Optimize the database' => 'Optimalizovat databázi',
    '(VACUUM command)' => '(příkaz VACUUM)',
    '(Gzip compressed Sqlite file)' => '(Gzip komprimovaný soubor Sqlite)',
    'Close a task' => 'Zavřít úkol',
    'Column' => 'Sloupec',
    'Color' => 'Barva',
    'Assignee' => 'Přiřazeno uživateli',
    'Create another task' => 'Vytvořit další úkol',
    'New task' => 'Nový úkol',
    'Open a task' => 'Otevřít úkol',
    'Do you really want to open this task: "%s"?' => 'Opravdu chcete znovuotevřít tento úkol: "%s"?',
    'Back to the board' => 'Zpět na nástěnku',
    'There is nobody assigned' => 'Není přiřazeno žádnému uživateli',
    'Column on the board:' => 'Sloupec na tabuli:',
    'Close this task' => 'Uzavřít úkol',
    'Open this task' => 'Otevřít tento úkol',
    'There is no description.' => 'Bez popisu',
    'Add a new task' => 'Přidat nový úkol',
    'The username is required' => 'Uživatelské jméno je vyžadováno',
    'The maximum length is %d characters' => 'Maximální délka je %d znaků',
    'The minimum length is %d characters' => 'Minimální délka je %d znaků',
    'The password is required' => 'Heslo je vyžadováno',
    'This value must be an integer' => 'Je vyžadována číselná hodnota',
    'The username must be unique' => 'Uživatelské jméno musí být jedinečné',
    'The user id is required' => 'Uživatelské ID je vyžadováno',
    'Passwords don\'t match' => 'Heslo se neshoduje',
    'The confirmation is required' => 'Je vyžadováno potvrzení',
    'The project is required' => 'Projekt je vyžadován',
    'The id is required' => 'ID je vyžadováno',
    'The project id is required' => 'ID projektu je vyžadováno',
    'The project name is required' => 'Jméno projektu je vyžadováno',
    'The title is required' => 'Nadpis je vyžadován',
    'Settings saved successfully.' => 'Nastavení bylo úspěšně uloženo',
    'Unable to save your settings.' => 'Vaše nastavení nelze uložit.',
    'Database optimization done.' => 'Optimalizace databáze byla provedena.',
    'Your project has been created successfully.' => 'Projekt byl úspěšně vytvořen.',
    'Unable to create your project.' => 'Projekt nelze vytvořit.',
    'Project updated successfully.' => 'Projekt byl úspěšně aktualizován',
    'Unable to update this project.' => 'Projekt nebylo možné aktualizovat.',
    'Unable to remove this project.' => 'Projekt nebylo možné odstranit.',
    'Project removed successfully.' => 'Projekt byl odstraněn.',
    'Project activated successfully.' => 'Projekt byl povolen.',
    'Unable to activate this project.' => 'Aktivace projektu selhala.',
    'Project disabled successfully.' => 'Projekt byl zakázán.',
    'Unable to disable this project.' => 'Zakázání projektu selhalo.',
    'Unable to open this task.' => 'Nelze otevření tento úkol.',
    'Task opened successfully.' => 'Úkol byl úspěšně otevřen.',
    'Unable to close this task.' => 'Nelze uzavřít tento úkol.',
    'Task closed successfully.' => 'Úkol byl úspěšně uzavřen.',
    'Unable to update your task.' => 'Aktualizace úkolu se nezdařila.',
    'Task updated successfully.' => 'Úkol byl úspěšně aktualizován.',
    'Unable to create your task.' => 'Úkol nelze vytvořit.',
    'Task created successfully.' => 'Úkol byl úspěšně vytvořen.',
    'User created successfully.' => 'Uživatel byl úspěšně vytvořen.',
    'Unable to create your user.' => 'Uživatele nebylo možné vytvořit.',
    'User updated successfully.' => 'Uživatel byl úspěšně aktualizován.',
    'User removed successfully.' => 'Uživatel byl vymazán.',
    'Unable to remove this user.' => 'Uživatele nebylo možné odebrat.',
    'Board updated successfully.' => 'Nástěnka byla úspěšně aktualizována.',
    'Ready' => 'Připraveno',
    'Backlog' => 'Nevyřízené',
    'Work in progress' => 'V řešení',
    'Done' => 'Dokončeno',
    'Application version:' => 'Verze aplikace:',
    'Id' => 'ID',
    'Public link' => 'Veřejný odkaz',
    'Timezone' => 'Časová zóna',
    'Sorry, I didn\'t find this information in my database!' => 'Omlouváme se, tuto informaci nelze nalézt!',
    'Page not found' => 'Stránka nenalezena',
    'Complexity' => 'Složitost',
    'Task limit' => 'Maximální počet úkolů',
    'Task count' => 'Počet úkolů',
    'User' => 'Uživatel',
    'Comments' => 'Komentáře',
    'Comment is required' => 'Komentář je vyžadován',
    'Comment added successfully.' => 'Komentář byl úspěšně přidán.',
    'Unable to create your comment.' => 'Komentář nelze vytvořit.',
    'Due Date' => 'Datum splnění',
    'Invalid date' => 'Neplatné datum',
    'Automatic actions' => 'Automaticky vykonávané akce',
    'Your automatic action has been created successfully.' => 'Vaše akce byla úspěšně vytvořena.',
    'Unable to create your automatic action.' => 'Vaší akci nebylo možné vytvořit.',
    'Remove an action' => 'Odstranit akci',
    'Unable to remove this action.' => 'Tuto akci nelze odstranit.',
    'Action removed successfully.' => 'Akce byla úspěšně odstraněna.',
    'Automatic actions for the project "%s"' => 'Automaticky vykonávané akce pro projekt "%s"',
    'Add an action' => 'Přidat akci',
    'Event name' => 'Název události',
    'Action' => 'Akce',
    'Event' => 'Událost',
    'When the selected event occurs execute the corresponding action.' => 'Kdykoliv se vybraná událost objeví, vykonat odpovídající akci.',
    'Next step' => 'Další krok',
    'Define action parameters' => 'Definovat parametry akce',
    'Do you really want to remove this action: "%s"?' => 'Skutečně chcete odebrat tuto akci: "%s"?',
    'Remove an automatic action' => 'Odebrat automaticky prováděnou akci',
    'Assign the task to a specific user' => 'Přiřadit tento úkol konkrétnímu uživateli',
    'Assign the task to the person who does the action' => 'Přiřadit úkol osobě, která akci provádí',
    'Duplicate the task to another project' => 'Duplikovat úkol do jiného projektu',
    'Move a task to another column' => 'Přesun úkolu do jiného sloupce',
    'Task modification' => 'Modifikace úkolu',
    'Task creation' => 'Vytváření úkolu',
    'Closing a task' => 'Uzavření úkolu',
    'Assign a color to a specific user' => 'Přiřadit barvu konkrétnímu uživateli',
    'Position' => 'Pozice',
    'Duplicate to project' => 'Vytvořit kopii v jiném projektu',
    'Duplicate' => 'Vytvořit kopii',
    'Link' => 'Odkaz',
    'Comment updated successfully.' => 'Komentář byl úspěšně aktualizován.',
    'Unable to update your comment.' => 'Nelze upravit Váš komentář.',
    'Remove a comment' => 'Odebrat komentář',
    'Comment removed successfully.' => 'Komentář byl smazán.',
    'Unable to remove this comment.' => 'Komentář nelze odebrat.',
    'Do you really want to remove this comment?' => 'Skutečně chcete odebrat tento komentář?',
    'Current password for the user "%s"' => 'Aktuální heslo pro uživatele "%s"',
    'The current password is required' => 'Heslo je vyžadováno',
    'Wrong password' => 'Neplatné heslo',
    'Unknown' => 'Neznámý',
    'Last logins' => 'Poslední přihlášení',
    'Login date' => 'Datum přihlášení',
    'Authentication method' => 'Autentifikační metoda',
    'IP address' => 'IP adresa',
    'User agent' => 'User Agent',
    'Persistent connections' => 'Trvalé připojení',
    'No session.' => 'doposud žádná relace.',
    'Expiration date' => 'Datum expirace',
    'Remember Me' => 'Zapamatovat si',
    'Creation date' => 'Datum vytvoření',
    'Everybody' => 'Kdokoliv',
    'Open' => 'Otevřené',
    'Closed' => 'Uzavřené',
    'Search' => 'Vyhledat',
    'Nothing found.' => 'Nenalezena žádná položka.',
    'Due date' => 'Plánovaný termín',
    'Description' => 'Podrobný popis',
    '%d comments' => '%d komentářů',
    '%d comment' => '%d komentář',
    'Email address invalid' => 'Neplatná e-mailová adresa',
    'Your external account is not linked anymore to your profile.' => 'Váš externí účet již není propojen s vaším profilem.',
    'Unable to unlink your external account.' => 'Nelze odpojit externí účet.',
    'External authentication failed' => 'Selhalo externí ověřování',
    'Your external account is linked to your profile successfully.' => 'Váš externí účet je úspěšně propojen s vaším profilem.',
    'Email' => 'E-Mail',
    'Task removed successfully.' => 'Úkol byl úspěšně odebrán.',
    'Unable to remove this task.' => 'Tento úkol nelze odebrat.',
    'Remove a task' => 'Odebrat úkol',
    'Do you really want to remove this task: "%s"?' => 'Opravdu chcete odebrat úkol: "%s"?',
    'Assign automatically a color based on a category' => 'Automaticky přiřadit barvu v závislosti na kategorii',
    'Assign automatically a category based on a color' => 'Automaticky přiřadit kategorii v závislosti na barvě',
    'Task creation or modification' => 'Vytváření nebo úprava úkolu',
    'Category' => 'Kategorie',
    'Category:' => 'Kategorie:',
    'Categories' => 'Kategorie',
    'Your category has been created successfully.' => 'Kategorie byla úspěšně vytvořena.',
    'This category has been updated successfully.' => 'Kategorie byla úspěšně aktualizována.',
    'Unable to update this category.' => 'Kategorii nelze aktualizovat.',
    'Remove a category' => 'Odstranit kategorii',
    'Category removed successfully.' => 'Kategorie byla odstraněna.',
    'Unable to remove this category.' => 'Kategorie nemhla být odstraněna.',
    'Category modification for the project "%s"' => 'Aktualizace kategoire pro projekt "%s" ',
    'Category Name' => 'Název kategorie',
    'Add a new category' => 'Přidat kategorii',
    'Do you really want to remove this category: "%s"?' => 'Skutečně chcete odebrat kategorii: "%s"?',
    'All categories' => 'Všechny kategorie',
    'No category' => 'Žádná kategorie',
    'The name is required' => 'Název je vyžadován',
    'Remove a file' => 'Odstranit sougor',
    'Unable to remove this file.' => 'Soubor nelze odebrat.',
    'File removed successfully.' => 'Soubor byl úspěšně odebrán.',
    'Attach a document' => 'Vložit dokument',
    'Do you really want to remove this file: "%s"?' => 'Skutečně chcete odebrat soubor: "%s"?',
    'Attachments' => 'Přílohy',
    'Edit the task' => 'Upravit úkol',
    'Add a comment' => 'Přidat komentář',
    'Edit a comment' => 'Upravit komentář',
    'Summary' => 'Souhrn',
    'Time tracking' => 'Sledování času',
    'Estimate:' => 'Odhad:',
    'Spent:' => 'Stráveno:',
    'Do you really want to remove this sub-task?' => 'Skutečně chcete odebrat dílčí úkol?',
    'Remaining:' => 'Zbývá:',
    'hours' => 'hodin',
    'estimated' => 'odhadnuto',
    'Sub-Tasks' => 'Dílčí úkoly',
    'Add a sub-task' => 'Přidat dílčí úkol',
    'Original estimate' => 'Časový odhad',
    'Create another sub-task' => 'Vytvořit další dílčí úkol',
    'Time spent' => 'Strávený čas',
    'Edit a sub-task' => 'Upravid dílčí úkol',
    'Remove a sub-task' => 'Odstranit dílčí úkol',
    'The time must be a numeric value' => 'Zadejte numerickou hodnotu času',
    'Todo' => 'Seznam úkolů',
    'In progress' => 'Zpracováváme',
    'Sub-task removed successfully.' => 'Dílčí úkol byl smazán.',
    'Unable to remove this sub-task.' => 'Tento dílčí úkol nelze odebrat.',
    'Sub-task updated successfully.' => 'Dílčí úkol byl aktualizován.',
    'Unable to update your sub-task.' => 'Nelze aktualizovat dílčí úkol.',
    'Unable to create your sub-task.' => 'Nelze vytvořit dílčí úkol.',
    'Maximum size: ' => 'Maximální velikost: ',
    'Display another project' => 'Zobrazit jiný projekt',
    'Created by %s' => 'Vytvořeno uživatelem %s',
    'Tasks Export' => 'Export úkolů',
    'Start Date' => 'Počáteční datum',
    'Execute' => 'Spustit',
    'Task Id' => 'Úkol ID',
    'Creator' => 'Vlastník',
    'Modification date' => 'Datum úpravy',
    'Completion date' => 'Datum dokončení',
    'Clone' => 'Kopie',
    'Project cloned successfully.' => 'Kopie projektu byla úspěšně vytvořena.',
    'Unable to clone this project.' => 'Kopii projektu nelze vytvořit.',
    'Enable email notifications' => 'Povolit upozornění pomocí e-mailů',
    'Task position:' => 'Pořadí úkolu:',
    'The task #%d has been opened.' => 'Úkol #%d byl znovu otevřen.',
    'The task #%d has been closed.' => 'Úkol #%d byl uzavřen.',
    'Sub-task updated' => 'Dílčí úkol byl aktualizován',
    'Title:' => 'Nadpis:',
    'Status:' => 'Stav:',
    'Assignee:' => 'Přiřazeno:',
    'Time tracking:' => 'Sledování času:',
    'New sub-task' => 'Nový dílčí úkol',
    'New attachment added "%s"' => 'Byla přidána nová příloha "%s".',
    'New comment posted by %s' => 'Nový komentář publikovaný uživatelem %s',
    'New comment' => 'Nový komentář',
    'Comment updated' => 'Komentář byl aktualizován.',
    'New subtask' => 'Nový dílčí úkol',
    'I only want to receive notifications for these projects:' => 'Přeji si dostávat upozornění pouze pro následující projekty:',
    'view the task on Kanboard' => 'Zobrazit úkol na Kanboard',
    'Public access' => 'Veřejný přístup',
    'Disable public access' => 'Zakázat veřejný přístup',
    'Enable public access' => 'Povolit veřejný přístup',
    'Public access disabled' => 'Veřejný přístup zakázán',
    'Move the task to another project' => 'Přesunout úkol do jiného projektu',
    'Move to project' => 'Přesunout do jiného projektu',
    'Do you really want to duplicate this task?' => 'Opravdu chcete vytořit kopii tohoto úkolu?',
    'Duplicate a task' => 'Vytvořit kopii úkolu',
    'External accounts' => 'Externí účty',
    'Account type' => 'typ účtu',
    'Local' => 'Lokální',
    'Remote' => 'Vzdálený',
    'Enabled' => 'Povoleno',
    'Disabled' => 'Zakázáno',
    'Login:' => 'Uživatelské jméno:',
    'Full Name:' => 'Jméno:',
    'Email:' => 'e-mail',
    'Notifications:' => 'Upozornění:',
    'Notifications' => 'Upozornění',
    'Account type:' => 'Typ účtu:',
    'Edit profile' => 'Upravit profil',
    'Change password' => 'Změnit heslo',
    'Password modification' => 'Změna hesla',
    'External authentications' => 'Vzdálená autorizace',
    'Never connected.' => 'Zatím nikdy nespojen.',
    'No external authentication enabled.' => 'Není povolena žádná vzdálená autorizace.',
    'Password modified successfully.' => 'Heslo bylo úspěšně změněno.',
    'Unable to change the password.' => 'Nelze změnit heslo.',
    'Change category' => 'Změnit kategorii',
    '%s updated the task %s' => '%s aktualizoval úkol %s ',
    '%s opened the task %s' => '%s znovu otevřel úkol %s ',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s přesunul úkol %s na pozici #%d ve sloupci "%s" ',
    '%s moved the task %s to the column "%s"' => '%s přesunul úkol %s do sloupce "%s" ',
    '%s created the task %s' => '%s vytvořil úkol %s ',
    '%s closed the task %s' => '%s uzavřel úkol %s ',
    '%s created a subtask for the task %s' => '%s vytvořil dílčí úkol pro úkol %s ',
    '%s updated a subtask for the task %s' => '%s aktualizoval dílčí úkol pro úkol %s ',
    'Assigned to %s with an estimate of %s/%sh' => 'Přiřazeno uživateli %s  s časovým odhadem práce %s/%s dní',
    'Not assigned, estimate of %sh' => 'Nepřiřazeno, časový odhad práce je %s dní',
    '%s updated a comment on the task %s' => '%s aktualizoval komentář k úkolu %s ',
    '%s commented the task %s' => '%s přidal komentář k úkolu %s ',
    '%s\'s activity' => 'Aktivity projektu %s',
    'RSS feed' => 'RSS kanál',
    '%s updated a comment on the task #%d' => '%s aktualizoval komnetář k úkolu #%d ',
    '%s commented on the task #%d' => '%s přidal komentář k úkolu #%d ',
    '%s updated a subtask for the task #%d' => '%s aktualizoval dílčí úkol úkolu #%d ',
    '%s created a subtask for the task #%d' => '%s vytvořil dílčí úkol úkolu #%d ',
    '%s updated the task #%d' => '%s aktualizoval úkol #%d ',
    '%s created the task #%d' => '%s vytvořil úkol #%d ',
    '%s closed the task #%d' => '%s uzavřel úkol #%d ',
    '%s opened the task #%d' => '%s znovu otevřel úkol #%d ',
    'Activity' => 'Aktivity',
    'Default values are "%s"' => 'Standardní hodnoty jsou: "%s"',
    'Default columns for new projects (Comma-separated)' => 'Výchozí sloupce pro nové projekty (odděleny čárkou)',
    'Task assignee change' => 'Změna přiřazení uživatelů',
    '%s changed the assignee of the task #%d to %s' => '%s změnil přidělení úkolu #%d na uživatele %s',
    '%s changed the assignee of the task %s to %s' => '%s změnil přidělení úkolu %s na uživatele %s',
    'New password for the user "%s"' => 'Nové heslo pro uživatele "%s"',
    'Choose an event' => 'Vybrat událost',
    'Create a task from an external provider' => 'Vytvořit úkol externím poskytovatelem',
    'Change the assignee based on an external username' => 'Změnit přiřazení uživatele závislé na externím uživateli',
    'Change the category based on an external label' => 'Změnit kategorii závislou na externím popisku',
    'Reference' => 'Reference',
    'Label' => 'Značka',
    'Database' => 'Databáze',
    'About' => 'O projektu',
    'Database driver:' => 'Databázový ovladač:',
    'Board settings' => 'Nastavení nástěnky',
    'Webhook settings' => 'Webhook nastavení',
    'Reset token' => 'Token reset',
    'API endpoint:' => 'API endpoint',
    'Refresh interval for personal board' => 'Interval automatického obnovování pro osobní nástěnky',
    'Refresh interval for public board' => 'Interval automatického obnovování pro veřejné nástěnky',
    'Task highlight period' => 'Úkol zvýrazněného období',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Interval (v sekundách), ve kterém je považovány úpravy úkolů za aktuální (0 pro zakázání, 2 dny ve výchozím nastavení)',
    'Frequency in second (60 seconds by default)' => 'Frekvence v sekundách (60 sekund ve výchozím nastavení)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frekvence v sekundách (0 pro zákaz této vlastnosti, 10 sekund ve výchozím nastavení)',
    'Application URL' => 'URL aplikace',
    'Token regenerated.' => 'Token byl opětovně generován.',
    'Date format' => 'Formát data',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO formát je vždy akceptován, například: "%s" a "%s"',
    'New personal project' => 'Nový osobní projekt',
    'This project is personal' => 'Tento projekt je osobní',
    'Add' => 'Přidat',
    'Start date' => 'Počáteční datum',
    'Time estimated' => 'Odhadovaný čas',
    'There is nothing assigned to you.' => 'Nemáte přiřazenou žádnou položku.',
    'My tasks' => 'Moje úkoly',
    'Activity stream' => 'Přehled aktivit',
    'Dashboard' => 'Nástěnka',
    'Confirmation' => 'Potvrzení',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Vytvořit komentář pomocí externího poskytovatele',
    'Project management' => 'Správa projektů',
    'Columns' => 'Sloupce',
    'Task' => 'Úkol',
    'Percentage' => 'Procenta',
    'Number of tasks' => 'Počet úkolů',
    'Task distribution' => 'Rozdělení úkolů',
    'Analytics' => 'Analýza',
    'Subtask' => 'Dílčí úkoly',
    'User repartition' => 'Rozdělení podle uživatelů',
    'Clone this project' => 'Duplokovat projekt',
    'Column removed successfully.' => 'Sloupec byl odstraněn.',
    'Not enough data to show the graph.' => 'Pro zobrazení grafu není dostatek dat.',
    'Previous' => 'Předchozí',
    'The id must be an integer' => 'ID musí být celé číslo',
    'The project id must be an integer' => 'ID projektu musí být celé číslo',
    'The status must be an integer' => 'Status musí být celé číslo',
    'The subtask id is required' => 'Je požadováno id dílčího úkolu',
    'The subtask id must be an integer' => 'ID dílčího úkolu musí být číslo',
    'The task id is required' => 'ID úkolu je povinné',
    'The task id must be an integer' => 'ID úkolu musí být číslo',
    'The user id must be an integer' => 'ID uživatele musí být číslo',
    'This value is required' => 'Hodnota je povinná',
    'This value must be numeric' => 'Hodnota musí být číselná',
    'Unable to create this task.' => 'Nelze vytvořit tento úkol',
    'Cumulative flow diagram' => 'Kumulativní diagram',
    'Daily project summary' => 'Denní přehledy',
    'Daily project summary export' => 'Export denních přehledů',
    'Exports' => 'Exporty',
    'This export contains the number of tasks per column grouped per day.' => 'Tento export obsahuje počet úkolů pro jednotlivé sloupce seskupených podle dní.',
    'Active swimlanes' => 'Aktivní dráhy',
    'Add a new swimlane' => 'Přidat novou dráhu',
    'Default swimlane' => 'Výchozí dráha',
    'Do you really want to remove this swimlane: "%s"?' => 'Opravdu si přejete odstranit tuto dráhu: "%s"?',
    'Inactive swimlanes' => 'Neaktivní dráha',
    'Remove a swimlane' => 'Odstranit dráhu',
    'Swimlane modification for the project "%s"' => 'Změny dráhy pro projekt "%s"',
    'Swimlane removed successfully.' => 'Dráha byla odstraněna.',
    'Swimlanes' => 'Dráhy',
    'Swimlane updated successfully.' => 'Dráha byla upravena.',
    'Unable to remove this swimlane.' => 'Tuto dráhu nelze odstranit.',
    'Unable to update this swimlane.' => 'Tuto dráhu nelze upravit.',
    'Your swimlane has been created successfully.' => 'Dráha byla vytvořena.',
    'Example: "Bug, Feature Request, Improvement"' => 'Například: "Chyba", "Nápad", "Požadavek"...',
    'Default categories for new projects (Comma-separated)' => 'Výchozí kategorie pro nové projekty (oddělené čárkou)',
    'Integrations' => 'Integrace',
    'Integration with third-party services' => 'Integrace se službami třetích stran',
    'Subtask Id' => 'Dílčí úkol Id',
    'Subtasks' => 'Dílčí úkoly',
    'Subtasks Export' => 'Export dílčích úkolů',
    'Task Title' => 'Název úkolu',
    'Untitled' => 'bez názvu',
    'Application default' => 'Standardní hodnoty',
    'Language:' => 'Jazyk:',
    'Timezone:' => 'Časová zóna:',
    'All columns' => 'Všechny sloupce',
    'Next' => 'Další',
    '#%d' => '#%d',
    'All swimlanes' => 'Alle Swimlanes',
    'All colors' => 'Všechny barvy',
    'Moved to column %s' => 'Přesunuto do sloupce %s ',
    'User dashboard' => 'Nástěnka uživatele',
    'Allow only one subtask in progress at the same time for a user' => 'Umožnit uživateli práci pouze na jednom dílčím úkolu ve stejném čase',
    'Edit column "%s"' => 'Upravit sloupec "%s" ',
    'Select the new status of the subtask: "%s"' => 'Vyberte nový stav pro dílčí úkol: "%s"',
    'Subtask timesheet' => 'Časový rozvrh dílčích úkolů',
    'There is nothing to show.' => 'Žádná položka k zobrazení',
    'Time Tracking' => 'Sledování času',
    'You already have one subtask in progress' => 'Jeden dílčí úkol již aktuálně řešíte',
    'Which parts of the project do you want to duplicate?' => 'Které části projektu  chcete duplikovat?',
    'Disallow login form' => 'Zakázat přihlašovací formulář',
    'Start' => 'Začátek',
    'End' => 'Konec',
    'Task age in days' => 'Doba trvání úkolu ve dnech',
    'Days in this column' => 'Dní v tomto sloupci',
    '%dd' => '%dd',
    'Add a new link' => 'Přidat nový odkaz',
    'Do you really want to remove this link: "%s"?' => 'Opravdu chcete odstranit odkaz "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Opravdu chcete odstranit odkaz na úkol #%d ?',
    'Field required' => 'Povinné pole',
    'Link added successfully.' => 'Propojení bylo úspěšně přidáno.',
    'Link updated successfully.' => 'Propojení bylo úspěšně aktualizováno.',
    'Link removed successfully.' => 'Propojení bylo úspěšně odebráno.',
    'Link labels' => 'Seznam odkazů',
    'Link modification' => 'Úpravy odkazů',
    'Opposite label' => 'Opačný text',
    'Remove a link' => 'Odstranit odkaz',
    'The labels must be different' => 'názvy musí být odlišné',
    'There is no link.' => 'Nejsou zde žádné odkazy',
    'This label must be unique' => 'Tento název musí být jedinečný',
    'Unable to create your link.' => 'Nelze vytvořit toto propojení.',
    'Unable to update your link.' => 'Nelze aktualizovat toto propojení.',
    'Unable to remove this link.' => 'Nelze odstranit toto propojení',
    'relates to' => 'souvisí s',
    'blocks' => 'blokuje',
    'is blocked by' => 'je blokován',
    'duplicates' => 'duplikuje',
    'is duplicated by' => 'je duplikován',
    'is a child of' => 'je podřízený',
    'is a parent of' => 'je nadřízený',
    'targets milestone' => 'patří k milníku',
    'is a milestone of' => 'je milníkem',
    'fixes' => 'nahrazuje',
    'is fixed by' => 'je nahrazen',
    'This task' => 'Tento úkol',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Rozbalit úkoly',
    'Collapse tasks' => 'Sbalit úkoly',
    'Expand/collapse tasks' => 'Rozbalit / sbalit úkoly',
    'Close dialog box' => 'Zavřít dialogové okno',
    'Submit a form' => 'Odeslat formulář',
    'Board view' => 'Zobrazení nástěnky',
    'Keyboard shortcuts' => 'Klávesnicové zkratky',
    'Open board switcher' => 'Otevřít přepínač nástěnek',
    'Application' => 'Aplikace',
    'Compact view' => 'Kompaktní zobrazení',
    'Horizontal scrolling' => 'Horizontální rolování',
    'Compact/wide view' => 'Kompaktní/plné zobrazení',
    'Currency' => 'Měna',
    'Personal project' => 'Osobní projekt',
    'AUD - Australian Dollar' => 'AUD - Australský dolar',
    'CAD - Canadian Dollar' => 'CAD - kanadský dolar',
    'CHF - Swiss Francs' => 'CHF - švýcarský frank',
    'Custom Stylesheet' => 'Vlastní šablony stylů',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Britská Libra',
    'INR - Indian Rupee' => 'INR - Indická rupie',
    'JPY - Japanese Yen' => 'JPY - Japonský jen',
    'NZD - New Zealand Dollar' => 'NZD - Novozélandský dolar',
    // 'PEN - Peruvian Sol' => '',
    'RSD - Serbian dinar' => 'RSD - Srbský dinár',
    'CNY - Chinese Yuan' => 'CNY - čínský jüan',
    'USD - US Dollar' => 'USD - Americký dolar',
    'VES - Venezuelan Bolívar' => 'VES - Venezuelský bolívar',
    'Destination column' => 'Cílový sloupec',
    'Move the task to another column when assigned to a user' => 'Přesunout úkol do jiného sloupce, když je úkol přiřazen uživateli.',
    'Move the task to another column when assignee is cleared' => 'Přesunout úkol do jiného sloupce, když je pověření uživatele vymazáno.',
    'Source column' => 'Zdrojový sloupec',
    'Transitions' => 'Změny etap',
    'Executer' => 'Vykonavatel',
    'Time spent in the column' => 'Trvání jednotlivých etap',
    'Task transitions' => 'Přesuny úkolů',
    'Task transitions export' => 'Export přesunů mezi sloupci',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Tento seznam obsahuje všechny pohyby úkolů s daty, uživateli a časy strávenými na úkolu.',
    'Currency rates' => 'Aktuální kurzy',
    'Rate' => 'Kurz',
    'Change reference currency' => 'Změnit referenční měnu',
    'Reference currency' => 'Referenční měna',
    'The currency rate has been added successfully.' => 'Směnný kurz byl úspěšně přidán.',
    'Unable to add this currency rate.' => 'Nelze přidat tento směnný kurz',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s odstranil přiřazení úkolu %s ',
    'Information' => 'Informace',
    'Check two factor authentication code' => 'Zkontrolujte dvouúrovňový autentifikační klíč',
    'The two factor authentication code is not valid.' => 'Dvouúrovňový autentifikační klíč není platný.',
    'The two factor authentication code is valid.' => 'Dvouúrovňový autentifikační klíč je platný.',
    'Code' => 'Klíč',
    'Two factor authentication' => 'Dvouúrovňová autorizace',
    'This QR code contains the key URI: ' => 'Tento QR kód obsahuje adresu s klíčem: ',
    'Check my code' => 'Kontrola mého kódu',
    'Secret key: ' => 'Tajný klíč: ',
    'Test your device' => 'Test Vašeho zařízení',
    'Assign a color when the task is moved to a specific column' => 'Přiřadit barvu, když je úkol přesunut do konkrétního sloupce',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Burndown-Chart',
    'This chart show the task complexity over the time (Work Remaining).' => 'Graf zobrazuje složitost úkolů v čase (Zbývající práce).',
    'Screenshot taken %s' => 'Snímek obrazovky pořízen %s ',
    'Add a screenshot' => 'Přidat snímek obrazovky',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Pořiďte snímek obrazovky a v tomto poli stiskněte Ctrl+V nebo ⌘+V ',
    'Screenshot uploaded successfully.' => 'Snímek obrazovky byl úspěšně nahrán.',
    'SEK - Swedish Krona' => 'SEK - Schwedische Kronen',
    'Identifier' => 'Identifikátor',
    'Disable two factor authentication' => 'Zrušit dvouúrovňovou autorizaci',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Opravdu chcete vypnout dvouúrovňovou autentifikaci pro uživatele: "%s"?',
    'Edit link' => 'Upravit odkaz',
    'Start to type task title...' => 'Začněte zadávat název úkolu ...',
    'A task cannot be linked to itself' => 'Úkol nemůže být napojen na sebe',
    'The exact same link already exists' => 'Stejný odkaz již existuje',
    'Recurrent task is scheduled to be generated' => 'Plánované generování opakovaného úkolu',
    'Score' => 'Skóre',
    'The identifier must be unique' => 'Identifikátor musí být unikátní',
    'This linked task id doesn\'t exists' => 'Tento odkazovaný úkol neexistuje',
    'This value must be alphanumeric' => 'Tato hodnota musí být alfanumerická',
    'Edit recurrence' => 'Upravit opakování',
    'Generate recurrent task' => 'Generovat opakující se úkol',
    'Trigger to generate recurrent task' => 'Spouštěč pro generování opakujícího se úkolu',
    'Factor to calculate new due date' => 'Faktor pro výpočet nového data splnění',
    'Timeframe to calculate new due date' => 'Časové okno pro výpočet nového data splnění',
    'Base date to calculate new due date' => 'Výchozí datum pro výpočet nového data splnění',
    'Action date' => 'Datum akce',
    'Base date to calculate new due date: ' => 'Výchozí datum pro výpočet nového data splnění: ',
    'This task has created this child task: ' => 'Tento úkol vygeneroval následující dílčí úkol: ',
    'Day(s)' => 'Dny',
    'Existing due date' => 'Existující datum splnění',
    'Factor to calculate new due date: ' => 'Faktor pro výpočet nového data splnění: ',
    'Month(s)' => 'Měsíce',
    'This task has been created by: ' => 'Tento úkol vytvořil: ',
    'Recurrent task has been generated:' => 'Opakující se úkol vygeneroval: ',
    'Timeframe to calculate new due date: ' => 'Časové okno pro výpočet nového data splnění: ',
    'Trigger to generate recurrent task: ' => 'Spouštěč pro generování opakujícího se úkolu: ',
    'When task is closed' => 'Když je úkol uzavřen',
    'When task is moved from first column' => 'Když je úkol přesunut z prvního sloupce',
    'When task is moved to last column' => 'Když je úkol přesunut do posleního sloupce',
    'Year(s)' => 'Rok(y)',
    'Project settings' => 'Nastavení projektu',
    'Automatically update the start date' => 'Automaticky aktualizovat počáteční datum',
    'iCal feed' => 'iCal feed',
    'Preferences' => 'Předvolby',
    'Security' => 'Zabezpečení ',
    'Two factor authentication disabled' => 'Dvouúrovňová autorizace zakázána.',
    'Two factor authentication enabled' => 'Dvouúrovňová autorizace povolena.',
    'Unable to update this user.' => 'Uživatele nelze aktualizovat.',
    'There is no user management for personal projects.' => 'Pro osobní projekty není aplikována správa uživatelů.',
    'User that will receive the email' => 'Uživatel, který dostane E-mail',
    'Email subject' => 'E-mail Předmět',
    'Date' => 'Datum',
    'Add a comment log when moving the task between columns' => 'Přidat komentář když je úkol přesouván mezi sloupci',
    'Move the task to another column when the category is changed' => 'Přesunout úkol do jiného sloupce když je změněna kategorie',
    'Send a task by email to someone' => 'Poslat někomu úkol poštou',
    'Reopen a task' => 'Znovu otevřít úkol',
    'Notification' => 'Upozornění',
    '%s moved the task #%d to the first swimlane' => '%s přesunul úkol #%d do první dráhy',
    'Swimlane' => 'Dráha',
    '%s moved the task %s to the first swimlane' => '%s přesunul úkol %s do první dráhy',
    '%s moved the task %s to the swimlane "%s"' => '%s přesunul úkol %s do dráhy "%s"',
    'This report contains all subtasks information for the given date range.' => 'Report obsahuje všechny informace o dílčích úkolech pro daný časový úsek',
    'This report contains all tasks information for the given date range.' => 'Report obsahuje informace o všech úkolech pro daný časový úsek.',
    'Project activities for %s' => 'Aktivity projektu %s',
    'view the board on Kanboard' => 'Zobrazit nástěnku',
    'The task has been moved to the first swimlane' => 'Úkol byl přesunut do první dráhy',
    'The task has been moved to another swimlane:' => 'Úkol byl přesunut do další dráhy',
    'New title: %s' => 'Nový název: %s',
    'The task is not assigned anymore' => 'Úkol již není přidělen',
    'New assignee: %s' => 'přidělení: %s',
    'There is no category now' => 'Nyní neexistuje žádná kategorie',
    'New category: %s' => 'Nová kategorie: %s',
    'New color: %s' => 'Nová barva: %s',
    'New complexity: %d' => 'Nová složitost: %d',
    'The due date has been removed' => 'Datum dokončení byl odstraněn',
    'There is no description anymore' => 'Ještě neexistuje žádný popis',
    'Recurrence settings has been modified' => 'Nastavení opakování bylo změněno',
    'Time spent changed: %sh' => 'Strávený čas se změnil: %sh',
    'Time estimated changed: %sh' => 'Odhadovaný čas se změnil: %sh',
    'The field "%s" has been updated' => 'Sloupec "%s" byl upraven',
    'The description has been modified:' => 'Popis byl upraven:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Opravdu si přejete úkol "%s" uzavřít? (stejně jako všechny dílčí úkoly)',
    'I want to receive notifications for:' => 'Chci dostávat upozornění na:',
    'All tasks' => 'Všechny úkoly',
    'Only for tasks assigned to me' => 'pouze pro moje úkoly',
    'Only for tasks created by me' => 'pouze pro mnou vytvořené úkoly',
    'Only for tasks created by me and tasks assigned to me' => 'pouze pro mnou vytvořené a mě přiřazené úkoly',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Celkem pro všechny sloupce',
    'You need at least 2 days of data to show the chart.' => 'Potřebujete nejméně data ze dvou dnů pro zobrazení grafu',
    '<15m' => '<15min.',
    '<30m' => '<30min.',
    'Stop timer' => 'Zastavit časovač',
    'Start timer' => 'Spustit časovač',
    'My activity stream' => 'Přehled mých aktivit',
    'Search tasks' => 'Hledání úkolů',
    'Reset filters' => 'Resetovat filtry',
    'My tasks due tomorrow' => 'Moje zítřejší úkoly',
    'Tasks due today' => 'Dnešní úkoly',
    'Tasks due tomorrow' => 'Zítřejší úkoly',
    'Tasks due yesterday' => 'Včerejší úkoly',
    'Closed tasks' => 'Uzavřené úkoly',
    'Open tasks' => 'Otevřené úkoly',
    'Not assigned' => 'Nepřiřazené',
    'View advanced search syntax' => 'Zobrazit syntaxi rozšířeného vyhledávání',
    'Overview' => 'Přehled',
    'Board/Calendar/List view' => 'Nástěnka/Kalendář/Zobrazení seznamu',
    'Switch to the board view' => 'Přepnout na nástěnku',
    'Switch to the list view' => 'Přepnout na seznam zobrazení',
    'Go to the search/filter box' => 'Zobrazit vyhledávání/filtrování',
    'There is no activity yet.' => 'Doposud nejsou žádné aktivity.',
    'No tasks found.' => 'Nenalezen žádný úkol.',
    'Keyboard shortcut: "%s"' => 'Klávesová zkratka: "%s"',
    'List' => 'Seznam',
    'Filter' => 'Filtr',
    'Advanced search' => 'Rozšířené hledání',
    'Example of query: ' => 'Příklad dotazu: ',
    'Search by project: ' => 'Hledat podle projektu: ',
    'Search by column: ' => 'Hledat podle sloupce: ',
    'Search by assignee: ' => 'Hledat podle přiřazené osoby: ',
    'Search by color: ' => 'Hledat podle barvy: ',
    'Search by category: ' => 'Hledat podle kategorie: ',
    'Search by description: ' => 'Hledat podle popisu: ',
    'Search by due date: ' => 'Hledat podle termínu: ',
    'Average time spent in each column' => 'Průměrná doba strávená v každé fázi',
    'Average time spent' => 'Průměrná strávená doba',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Tento graf ukazuje průměrný čas strávený v každém sloupci pro poslední úkoly %d.',
    'Average Lead and Cycle time' => 'Průměrná dodací lhůta a doba cyklu',
    'Average lead time: ' => 'Průměrná dodací lhůta: ',
    'Average cycle time: ' => 'Průměrná doba cyklu: ',
    'Cycle Time' => 'Doba cyklu',
    'Lead Time' => 'Dodací lhůta',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Graf ukazuje průměrnou dodací lhůtu a dobu cyklu pro posledních %d úkolů v průběhu času',
    'Average time into each column' => 'Průměrná doba v každé fázi',
    'Lead and cycle time' => 'Dodací lhůta a doba cyklu',
    'Lead time: ' => 'Dodací lhůta: ',
    'Cycle time: ' => 'Doba cyklu: ',
    'Time spent in each column' => 'Čas strávený v každé fázi',
    'The lead time is the duration between the task creation and the completion.' => 'Lead time (dodací lhůta) je čas od založení úkolu do jeho dokončení.',
    'The cycle time is the duration between the start date and the completion.' => 'Doba cyklu je doba trvání mezi zahájením a dokončením úkolu.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Jestliže není úkol uzavřen, místo termínu dokončení je použit aktuální čas.',
    'Set the start date automatically' => 'Nastavit automaticky počáteční datum',
    'Edit Authentication' => 'Upravit ověřování',
    'Remote user' => 'Vzdálený uživatel',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Hesla vzdáleným uživatelům se neukládají do databáze Kanboard. Naříklad: LDAP, Google a Github účty.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Pokud zaškrtnete políčko "Zakázat přihlašovací formulář", budou pověření zadané do přihlašovacího formuláře ignorovány.',
    'Default task color' => 'Výchozí barva úkolu',
    'This feature does not work with all browsers.' => 'Tato funkcionalita nefunguje ve všech prohlížečích.',
    'There is no destination project available.' => 'Není dostupný žádný cílový projekt.',
    'Trigger automatically subtask time tracking' => 'Spouštět automaticky dílčí úkol sledování času',
    'Include closed tasks in the cumulative flow diagram' => 'začlenit dokončené úkoly do kumulativního flow diagramu',
    'Current swimlane: %s' => 'Aktuální swimlane: %s',
    'Current column: %s' => 'Aktuální fáze: %s',
    'Current category: %s' => 'Aktuální kategorie: %s',
    'no category' => 'kategorie nenastavena',
    'Current assignee: %s' => 'Aktuálně přiřazený uživatel: %s',
    'not assigned' => 'nepřiřazeno',
    'Author:' => 'Autor:',
    'contributors' => 'přispěvatelé',
    'License:' => 'Licence:',
    'License' => 'Licence',
    'Enter the text below' => 'Zadejte text níže',
    'Start date:' => 'Termín zahájení:',
    'Due date:' => 'Termín dokončení:',
    'People who are project managers' => 'Lidé, kteří jsou správci projektu',
    'People who are project members' => 'Lidé, kteří jsou členové projektu',
    'NOK - Norwegian Krone' => 'NOK - Norská koruna',
    'Show this column' => 'Zobrazit tento sloupec',
    'Hide this column' => 'Skrýt tento sloupec',
    'End date' => 'Datum konce',
    'Users overview' => 'Přehled uživatelů',
    'Members' => 'Členové',
    'Shared project' => 'Sdílený projekt',
    'Project managers' => 'Správci projektu',
    'Projects list' => 'Seznam projektů',
    'End date:' => 'Datum konce: ',
    'Change task color when using a specific task link' => 'Změnit barvu úkolu při použití konkrétního odkazu na úkol',
    'Task link creation or modification' => 'Vytvoření, nebo změna odkazu na úkol',
    'Milestone' => 'Milník',
    'Reset the search/filter box' => 'Vyresetovat pole pro vyhledávání / filtrování',
    'Documentation' => 'Dokumentace',
    'Author' => 'Autor',
    'Version' => 'Verze',
    'Plugins' => 'Pluginy',
    'There is no plugin loaded.' => 'Není nainstalován plugin.',
    'My notifications' => 'Moje oznámení',
    'Custom filters' => 'Vlastní filtry',
    'Your custom filter has been created successfully.' => 'Vlastní filtr byl úspěšně vytvořen.',
    'Unable to create your custom filter.' => 'Nelze vytvořit vlastní filtr.',
    'Custom filter removed successfully.' => 'Vlastní filtr byl úspěšně odebrán.',
    'Unable to remove this custom filter.' => 'Nelze odebrat tento vlastní filtr.',
    'Edit custom filter' => 'Upravit vlastní filtr',
    'Your custom filter has been updated successfully.' => 'Vlastní filtr byl úspěšně aktualizován.',
    'Unable to update custom filter.' => 'Nelze aktualizovat vlastní filtr.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Nová příloha u úkolu #%d: %s',
    'New comment on task #%d' => 'Nový komentář u úkolu #%d',
    'Comment updated on task #%d' => 'Komentář u úkolu #%d byl aktualizován',
    'New subtask on task #%d' => 'Nový dílčí úkol u úkolu #%d',
    'Subtask updated on task #%d' => 'Dílčí úkol u úkolu #%d byl aktualizován',
    'New task #%d: %s' => 'Nový úkol #%d: %s',
    'Task updated #%d' => 'Úkol #%d byl aktualizován',
    'Task #%d closed' => 'Úkol #%d byl uzavřen',
    'Task #%d opened' => 'Úkol #%d byl otevřen',
    'Column changed for task #%d' => 'Sloupec úkolu #%d byl změněn',
    'New position for task #%d' => 'Nová pozice úkolu #%d',
    'Swimlane changed for task #%d' => 'Dráha úkolu #%d byla změněna',
    'Assignee changed on task #%d' => 'Vlastník úkolu #%d byl změněn',
    '%d overdue tasks' => '%d úkolů po datu splnění',
    'Task #%d is overdue' => 'Úkol #%d je po datu splnění',
    'No notification.' => 'Žádná notifikace.',
    'Mark all as read' => 'Označit vše jako přečtené',
    'Mark as read' => 'Označit jako přečtené',
    'Total number of tasks in this column across all swimlanes' => 'Celkový počet úkolů v tomto sloupci napříč všemi dráhami',
    'Collapse swimlane' => 'Sbalit dráhu',
    'Expand swimlane' => 'Rozbalit dráhu',
    'Add a new filter' => 'Přidat nový filtr',
    'Share with all project members' => 'Sdílet se všemi členy projektu',
    'Shared' => 'Sdíleno',
    'Owner' => 'Vlastník',
    'Unread notifications' => 'Nepřečtené notifikace',
    'Notification methods:' => 'Způsoby notifikací:',
    'Unable to read your file' => 'Nelze přečíst soubor',
    '%d task(s) have been imported successfully.' => '%d úkol(y) byly úspěšně importovány.',
    'Nothing has been imported!' => 'Nic nebylo importováno!',
    'Import users from CSV file' => 'Import uživatele ze souboru CSV',
    '%d user(s) have been imported successfully.' => '%d uživatel(é) byl úspěšně importován.',
    'Comma' => 'Čárka',
    'Semi-colon' => 'Středník',
    'Tab' => 'Záložka',
    'Vertical bar' => 'Vertikální pruh',
    'Double Quote' => 'Dvojitá nabídka',
    'Single Quote' => 'Jediná nabídka',
    '%s attached a file to the task #%d' => '%s připojil soubor k úkolu #%d',
    'There is no column or swimlane activated in your project!' => 'Ve vašem projektu není aktivován žádný sloupec ani dráha!',
    'Append filter (instead of replacement)' => 'Přidat filtr (místo nahrazení)',
    'Append/Replace' => 'Přidat / Nahradit',
    'Append' => 'Přidat',
    'Replace' => 'Nahradit',
    'Import' => 'Import',
    'Change sorting' => 'Změnit třídění',
    'Tasks Importation' => 'Import úkolů',
    'Delimiter' => 'Oddělovač',
    'Enclosure' => 'Příloha',
    'CSV File' => 'Soubor CSV',
    'Instructions' => 'Instrukce',
    'Your file must use the predefined CSV format' => 'Váš soubor musí používat předdefinovaný formát CSV',
    'Your file must be encoded in UTF-8' => 'Soubor musí být zakódován v UTF-8',
    'The first row must be the header' => 'První řádek musí být záhlaví',
    'Duplicates are not verified for you' => 'Duplikáty pro vás nejsou ověřeny',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Datum vypršení musí být ve formátu ISO: RRRR-MM-DD',
    'Download CSV template' => 'Stáhnout šablonu CSV',
    'No external integration registered.' => 'Není registrována žádná externí integrace.',
    'Duplicates are not imported' => 'Duplikáty nejsou importovány',
    'Usernames must be lowercase and unique' => 'Uživatelská jména musí být malá a jedinečná',
    'Passwords will be encrypted if present' => 'Hesla budou šifrována, pokud jsou přítomna',
    '%s attached a new file to the task %s' => '%s připojil nový úkol k úkolu %s',
    'Link type' => 'Typ odkazu',
    'Assign automatically a category based on a link' => 'Automaticky přiřadit kategorii na základě odkazu',
    'BAM - Konvertible Mark' => 'BAM - Konvertible Mark',
    'Assignee Username' => 'Uživatelské jméno postupníka',
    'Assignee Name' => 'Jméno postupníka',
    'Groups' => 'Skupiny',
    'Members of %s' => 'Členové %s',
    'New group' => 'Nová skupina',
    'Group created successfully.' => 'Skupina byla úspěšně vytvořena.',
    'Unable to create your group.' => 'Nelze vytvořit vaši skupinu.',
    'Edit group' => 'Upravit skupinu',
    'Group updated successfully.' => 'Skupina byla úspěšně aktualizována.',
    'Unable to update your group.' => 'Skupinu nelze aktualizovat.',
    'Add group member to "%s"' => 'Přidat člena skupiny do "%s"',
    'Group member added successfully.' => 'Člen skupiny byl úspěšně přidán.',
    'Unable to add group member.' => 'Nelze přidat člena skupiny.',
    'Remove user from group "%s"' => 'Odebrat uživatele ze skupiny "%s"',
    'User removed successfully from this group.' => 'Uživatel byl úspěšně odebrán z této skupiny.',
    'Unable to remove this user from the group.' => 'Nelze odebrat tohoto uživatele ze skupiny.',
    'Remove group' => 'Odebrat skupinu',
    'Group removed successfully.' => 'Skupina byla úspěšně odebrána.',
    'Unable to remove this group.' => 'Tuto skupinu nelze odebrat.',
    'Project Permissions' => 'Oprávnění projektu',
    'Manager' => 'Správce',
    'Project Manager' => 'Správce projektu',
    'Project Member' => 'Člen projektu',
    'Project Viewer' => 'Čtenář projektu',
    'Your account is locked for %d minutes' => 'Váš účet je uzamčen na %d minut',
    'Invalid captcha' => 'Neplatná captcha',
    'The name must be unique' => 'Název musí být jedinečný',
    'View all groups' => 'Zobrazit všechny skupiny',
    'There is no user available.' => 'Uživatel není k dispozici.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Opravdu chcete odstranit uživatele "%s" ze skupiny "%s"?',
    'There is no group.' => 'Neexistuje žádná skupina.',
    'Add group member' => 'Přidat člena skupiny',
    'Do you really want to remove this group: "%s"?' => 'Opravdu chcete tuto skupinu odstranit: "%s"?',
    'There is no user in this group.' => 'V této skupině není žádný uživatel.',
    'Permissions' => 'Oprávnění',
    'Allowed Users' => 'Povolení uživatelé',
    'No specific user has been allowed.' => 'Žádný uživatel nebyl výslovně povolen.',
    'Role' => 'Role',
    'Enter user name...' => 'Zadejte uživatelské jméno...',
    'Allowed Groups' => 'Povolené skupiny',
    'No group has been allowed.' => 'Žádná skupina nebyla povolena.',
    'Group' => 'Skupina',
    'Group Name' => 'Jméno skupiny',
    'Enter group name...' => 'Zadejte název skupiny ...',
    'Role:' => 'Role:',
    'Project members' => 'Členové projektu',
    '%s mentioned you in the task #%d' => '%s vás uvedl v úkolu #%d',
    '%s mentioned you in a comment on the task #%d' => '%s vás uvedl v komentáři k úkolu #%d',
    'You were mentioned in the task #%d' => 'Byli jste zmíněni v úkolu #%d',
    'You were mentioned in a comment on the task #%d' => 'Byli jste zmíněni v komentáři k úkolu #%d',
    'Estimated hours: ' => 'Odhad hodin: ',
    'Actual hours: ' => 'Aktuální hodiny: ',
    'Hours Spent' => 'Hodin stráveno',
    'Hours Estimated' => 'Hodin odhadováno',
    'Estimated Time' => 'Odhadovaný čas',
    'Actual Time' => 'Aktuální čas',
    'Estimated vs actual time' => 'Rozdíl mezi odhadovaným a aktuálním časem',
    'RUB - Russian Ruble' => 'RUB - ruský rubl',
    'Assign the task to the person who does the action when the column is changed' => 'Úkol přiřadit osobě, která provede akci při změně sloupce',
    'Close a task in a specific column' => 'Ukončete úlohu ve specifickém sloupci',
    'Time-based One-time Password Algorithm' => 'Algoritmus na časově závislé jednorázové heslo',
    'Two-Factor Provider: ' => 'Poskytovatel dvou faktorů: ',
    'Disable two-factor authentication' => 'Zakázat dvoufaktorovou autentizaci',
    'Enable two-factor authentication' => 'Povolit dvoufaktorovou autentizaci',
    'There is no integration registered at the moment.' => 'V tuto chvíli není registrována žádná integrace.',
    'Password Reset for Kanboard' => 'Reset hesla pro Kanboard',
    'Forgot password?' => 'Zapomenuté heslo?',
    'Enable "Forget Password"' => 'Povolit zapomenuté heslo',
    'Password Reset' => 'Resetovat heslo',
    'New password' => 'Nové heslo',
    'Change Password' => 'Změnit heslo',
    'To reset your password click on this link:' => 'Chcete-li heslo obnovit, klikněte na tento odkaz:',
    'Last Password Reset' => 'Poslední reset hesla',
    'The password has never been reinitialized.' => 'Heslo nebylo nikdy znovu inicializováno.',
    'Creation' => 'Vytvoření',
    'Expiration' => 'Vypršení',
    'Password reset history' => 'Historie resetování hesla',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Všechny úkoly ve sloupci "%s" a dráze "%s" byly úspěšně uzavřeny.',
    'Do you really want to close all tasks of this column?' => 'Opravdu chcete zavřít všechny úkoly tohoto sloupce?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d úkol(y) ve sloupci "%s" a dráha "%s" bude uzavřena.',
    'Close all tasks in this column and this swimlane' => 'Uzavřít všechny úkoly v tomto sloupci',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Žádný plugin není registrován na metodu oznamování projektu. Stále můžete konfigurovat jednotlivá oznámení v profilu uživatele.',
    'My dashboard' => 'Moje nástěnka',
    'My profile' => 'Můj profil',
    'Project owner: ' => 'Vlastník projektu: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Identifikátor projektu je nepovinný a musí být alfanumerický, například: MYPROJECT.',
    'Project owner' => 'Vlastník projektu',
    'Personal projects do not have users and groups management.' => 'Osobní projekty nemají správu uživatelů a skupin',
    'There is no project member.' => 'Projekt nemá žádného člena',
    'Priority' => 'Priorita',
    'Task priority' => 'Priorita úkolu',
    'General' => 'Všeobecné',
    'Dates' => 'Termíny',
    'Default priority' => 'Výchozí priorita',
    'Lowest priority' => 'Nejnižší priorita',
    'Highest priority' => 'Nejvyšší priorita',
    'Close a task when there is no activity' => 'Uzavřít úkol pokud není žádná aktivita',
    'Duration in days' => 'Trvání ve dnech',
    'Send email when there is no activity on a task' => 'Odeslat mail pokud není žádná aktivita u úkolu',
    'Unable to fetch link information.' => 'Nelze načíst informace o odkazu.',
    'Daily background job for tasks' => 'Denní práce na pozadí pro úkoly',
    'Auto' => 'Auto',
    'Related' => 'Související',
    'Attachment' => 'Příloha',
    'Title not found' => 'Název nenalezen',
    'Web Link' => 'Webový odkaz',
    'External links' => 'Externí odkazy',
    'Add external link' => 'Přidat externí odkaz',
    'Type' => 'Typ',
    'Dependency' => 'Závislost',
    'Add internal link' => 'Přidat interní odkaz',
    'Add a new external link' => 'Přidat nový externí odkaz',
    'Edit external link' => 'Upravit externí odkaz',
    'External link' => 'Externí odkaz',
    'Copy and paste your link here...' => 'Zde vložte váš odkaz...',
    'URL' => 'URL',
    'Internal links' => 'Interní odkazy',
    'Assign to me' => 'Přiřadit to mně',
    'Me' => 'Mně',
    'Do not duplicate anything' => 'Nekopírovat nic',
    'Projects management' => 'Správa projektů',
    'Users management' => 'Správa uživatelů',
    'Groups management' => 'Správa skupin',
    'Create from another project' => 'Vytvořit z jiného projektu',
    'open' => 'otevřeno',
    'closed' => 'uzavřeno',
    'Priority:' => 'Priorita:',
    'Reference:' => 'Odkaz:',
    'Complexity:' => 'Složitost:',
    'Swimlane:' => 'Dráha:',
    'Column:' => 'Sloupec:',
    'Position:' => 'Pozice:',
    'Creator:' => 'Autor:',
    'Time estimated:' => 'Odhadovaný čas:',
    '%s hours' => '%s hodin',
    'Time spent:' => 'Strávený čas:',
    'Created:' => 'Vytvořeno:',
    'Modified:' => 'Změněno:',
    'Completed:' => 'Dokončeno:',
    'Started:' => 'Započato:',
    'Moved:' => 'Přesunuto',
    'Task #%d' => 'Úkol #%d',
    'Time format' => 'Časový formát',
    'Start date: ' => 'Počáteční datum',
    'End date: ' => 'Koncové datum: ',
    'New due date: ' => 'Nové datum splnění: ',
    'Start date changed: ' => 'Počáteční datum změněno: ',
    'Disable personal projects' => 'Zakázat osobní projekty',
    'Do you really want to remove this custom filter: "%s"?' => 'Opravdu chcete odstranit tento vlastní filtr: "%s"?',
    'Remove a custom filter' => 'Odebrat vlastní filtr',
    'User activated successfully.' => 'Uživatel byl úspěšně aktivován.',
    'Unable to enable this user.' => 'Tohoto uživatele nelze aktivovat.',
    'User disabled successfully.' => 'Uživatel byl úspěšně zakázán.',
    'Unable to disable this user.' => 'Tohoto uživatele nelze vypnout.',
    'All files have been uploaded successfully.' => 'Všechny soubory byly úspěšně nahrány.',
    'The maximum allowed file size is %sB.' => 'Maximální povolená velikost souboru je %sB.',
    'Drag and drop your files here' => 'Přetáhnout soubory sem',
    'choose files' => 'zvolit soubory',
    'View profile' => 'Prohlédnout profil',
    'Two Factor' => 'Dva faktory',
    'Disable user' => 'Zakázat uživatele',
    'Do you really want to disable this user: "%s"?' => 'Opravdu chcete tohoto uživatele zakázat: "%s"?',
    'Enable user' => 'Povolit uživatele',
    'Do you really want to enable this user: "%s"?' => 'Opravdu chcete povolit tohoto uživatele: "%s"?',
    'Download' => 'Stáhnout',
    'Uploaded: %s' => 'Nahráno: %s',
    'Size: %s' => 'Velikost: %s',
    'Uploaded by %s' => 'Nahráno uživatelem %s',
    'Filename' => 'Název souboru',
    'Size' => 'Velikost',
    'Column created successfully.' => 'Sloupec byl úspěšně vytvořen.',
    'Another column with the same name exists in the project' => 'V projektu existuje další sloupec se stejným názvem',
    'Default filters' => 'Výchozí filtry',
    'Your board doesn\'t have any columns!' => 'Vaše deska nemá žádné sloupce',
    'Change column position' => 'Změnit polohu sloupce',
    'Switch to the project overview' => 'Přepnout do přehledu projektu',
    'User filters' => 'Uživatelské filtry',
    'Category filters' => 'Filtry kategorie',
    'Upload a file' => 'Nahrát soubor',
    'View file' => 'Prohlédnout soubor',
    'Last activity' => 'Poslední aktivita',
    'Change subtask position' => 'Změnit pozici dílčí úlohy',
    'This value must be greater than %d' => 'Tato hodnota musí být větší než %d',
    'Another swimlane with the same name exists in the project' => 'V projektu existuje další dráha se stejným názvem',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Příklad: https://example.kanboard.org/ (slouží k generování absolutních adres URL)',
    'Actions duplicated successfully.' => 'Akce byly úspěšně duplikovány.',
    'Unable to duplicate actions.' => 'Nelze duplikovat akce.',
    'Add a new action' => 'Přidat novou akci',
    'Import from another project' => 'Import z jiného projektu',
    'There is no action at the moment.' => 'V tuto chvíli neexistuje žádná akce.',
    'Import actions from another project' => 'Import akcí z jiného projektu',
    'There is no available project.' => 'Projekt není k dispozici.',
    'Local File' => 'Místní soubor',
    'Configuration' => 'Konfigurace',
    'PHP version:' => 'Verze PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Verze operačního systému:',
    'Database version:' => 'Verze databáze:',
    'Browser:' => 'Prohlížeč:',
    'Task view' => 'Zobrazení úkolů',
    'Edit task' => 'Upravit úkol',
    'Edit description' => 'Upravit popis',
    'New internal link' => 'Nový interní odkaz',
    'Display list of keyboard shortcuts' => 'Zobrazí seznam klávesových zkratek',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Nahrát obrázek mého avatara',
    'Remove my image' => 'Odebrat můj obrázek',
    'The OAuth2 state parameter is invalid' => 'Parametr stavu OAuth2 je neplatný',
    'User not found.' => 'Uživatel nenalezen.',
    'Search in activity stream' => 'Vyhledávání v toku činností',
    'My activities' => 'Moje aktivity',
    'Activity until yesterday' => 'Aktivita do včerejška',
    'Activity until today' => 'Aktivita dodnes',
    'Search by creator: ' => 'Vyhledávání podle autora: ',
    'Search by creation date: ' => 'Vyhledávání podle data vytvoření: ',
    'Search by task status: ' => 'Vyhledávání podle stavu úkolu: ',
    'Search by task title: ' => 'Vyhledávání podle názvu úkolu: ',
    'Activity stream search' => 'Vyhledávání aktivity',
    'Projects where "%s" is manager' => 'Projekty, kde "%s" je manažer',
    'Projects where "%s" is member' => 'Projekty, kde "%s" je člen',
    'Open tasks assigned to "%s"' => 'Otevřít úkoly přiřazené k "%s"',
    'Closed tasks assigned to "%s"' => 'Uzavřené úkoly přiřazené k "%s"',
    'Assign automatically a color based on a priority' => 'Automaticky přiřadit barvu podle priority',
    'Overdue tasks for the project(s) "%s"' => 'Zpožděné úkoly pro projekt(y) "%s"',
    'Upload files' => 'Nahrát soubory',
    'Installed Plugins' => 'Instalované moduly',
    'Plugin Directory' => 'Plugin adresář',
    'Plugin installed successfully.' => 'Plugin byl úspěšně nainstalován.',
    'Plugin updated successfully.' => 'Plugin byl úspěšně aktualizován.',
    'Plugin removed successfully.' => 'Plugin byl úspěšně odstraněn.',
    'Subtask converted to task successfully.' => 'Dílčí úkol úspěšně převeden na úkol.',
    'Unable to convert the subtask.' => 'Nelze převést dílčí úkol.',
    'Unable to extract plugin archive.' => 'Nelze extrahovat archiv pluginů.',
    'Plugin not found.' => 'Plugin nebyl nalezen.',
    'You don\'t have the permission to remove this plugin.' => 'Nemáte povolení odstranit tento plugin.',
    'Unable to download plugin archive.' => 'Nelze stáhnout archiv pluginů.',
    'Unable to write temporary file for plugin.' => 'Nelze zapsat dočasný soubor pro plugin.',
    'Unable to open plugin archive.' => 'Nelze otevřít archiv pluginu.',
    'There is no file in the plugin archive.' => 'V archivu pluginů není žádný soubor.',
    'Create tasks in bulk' => 'Vytvořit úkoly hromadně',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Instance Kanboard není nakonfigurována pro instalaci pluginů z uživatelského rozhraní.',
    'There is no plugin available.' => 'Není k dispozici žádný plugin.',
    'Install' => 'Nainstalovat',
    'Update' => 'Aktualizace',
    'Up to date' => 'Aktuální',
    'Not available' => 'Není dostupný',
    'Remove plugin' => 'Odebrat plugin',
    'Do you really want to remove this plugin: "%s"?' => 'Opravdu chcete tento plugin odstranit: "%s"?',
    'Uninstall' => 'Odinstalovat',
    'Listing' => 'Výpis',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Správa projektů',
    'Convert to task' => 'Převést na úkol',
    'Convert sub-task to task' => 'Převést dílčí úkol na úkol',
    'Do you really want to convert this sub-task to a task?' => 'Opravdu chcete převést tento dílčí úkol na úkol?',
    'My task title' => 'Můj název úkolu',
    'Enter one task by line.' => 'Zadejte jeden úkol na řádek.',
    'Number of failed login:' => 'Počet neúspěšných přihlášení:',
    'Account locked until:' => 'Účet uzamčen do:',
    'Email settings' => 'Nastavení e-mailu',
    'Email sender address' => 'Adresa odesílatele e-mailu',
    'Email transport' => 'E-mail transport',
    'Webhook token' => 'Token Webhook',
    'Project tags management' => 'Správa tagů projektu',
    'Tag created successfully.' => 'Značka byla úspěšně vytvořena.',
    'Unable to create this tag.' => 'Tuto značku nelze vytvořit.',
    'Tag updated successfully.' => 'Značka byla úspěšně aktualizována.',
    'Unable to update this tag.' => 'Tuto značku nelze aktualizovat.',
    'Tag removed successfully.' => 'Značka byla úspěšně odebrána.',
    'Unable to remove this tag.' => 'Tuto značku nelze odstranit.',
    'Global tags management' => 'Správa globálních značek',
    'Tags' => 'Štítky',
    'Tags management' => 'Správa štítků',
    'Add new tag' => 'Přidat nový štítek',
    'Edit a tag' => 'Upravit štítek',
    'Project tags' => 'Štítky projektu',
    'There is no specific tag for this project at the moment.' => 'Momentálně není pro tento projekt žádný specifický tag.',
    'Tag' => 'Štítek',
    'Remove a tag' => 'Odebrat značku',
    'Do you really want to remove this tag: "%s"?' => 'Opravdu chcete tuto značku odstranit: "%s"?',
    'Global tags' => 'Globální značky',
    'There is no global tag at the moment.' => 'Momentálně neexistuje globální značka.',
    'This field cannot be empty' => 'Toto pole nemůže být prázdné',
    'Close a task when there is no activity in a specific column' => 'Ukončit úlohu, pokud ve specifickém sloupci neexistuje žádná aktivita',
    '%s removed a subtask for the task #%d' => '%s odstranil dílčí úkol pro úkol #%d',
    '%s removed a comment on the task #%d' => '%s odstranil komentář k úkolu #%d',
    'Comment removed on task #%d' => 'Komentář byl odebrán na úkolu #%d',
    'Subtask removed on task #%d' => 'Dílčí úkol odstraněn na úkolu #%d',
    'Hide tasks in this column in the dashboard' => 'Skrýt úkoly v tomto sloupci v řídicím panelu',
    '%s removed a comment on the task %s' => '%s odstranil komentář k úkolu %s',
    '%s removed a subtask for the task %s' => '%s odstranil dílčí úkol pro úkol %s',
    'Comment removed' => 'Komentář byl odebrán',
    'Subtask removed' => 'Odstraněn dílčí úkol',
    '%s set a new internal link for the task #%d' => '%s nastavit nový interní odkaz pro úkol #%d',
    '%s removed an internal link for the task #%d' => '%s odstranil interní odkaz pro úkol #%d',
    'A new internal link for the task #%d has been defined' => 'Byl definován nový interní odkaz úkolu #%d',
    'Internal link removed for the task #%d' => 'Interní odkaz odstraněn pro úkol #%d',
    '%s set a new internal link for the task %s' => '%s nastavit nový interní odkaz pro úkol %s',
    '%s removed an internal link for the task %s' => '%s odstranil interní odkaz pro úkol %s',
    'Automatically set the due date on task creation' => 'Automaticky nastaví datum splatnosti úlohy',
    'Move the task to another column when closed' => 'Při zavření přesunout úkol do jiného sloupce',
    'Move the task to another column when not moved during a given period' => 'Přesunout úkol do jiného sloupce, pokud není přesunut během daného období',
    'Dashboard for %s' => 'Ovládací panel pro %s',
    'Tasks overview for %s' => 'Přehled úkolů pro %s',
    'Subtasks overview for %s' => 'Přehled dílčích úkolů pro%s',
    'Projects overview for %s' => 'Přehled projektů pro %s',
    'Activity stream for %s' => 'Proud aktivity pro %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Při přesunu úkolu na konkrétní dráhu přiřaďte barvu',
    'Assign a priority when the task is moved to a specific swimlane' => 'Při přesunu úkolu na konkrétní dráhu přiřaďte prioritu',
    'User unlocked successfully.' => 'Uživatel byl úspěšně odemčen.',
    'Unable to unlock the user.' => 'Nelze uživatele odemknout.',
    'Move a task to another swimlane' => 'Přemístěte úkol na jinou dráhu',
    'Creator Name' => 'Jméno tvůrce',
    'Time spent and estimated' => 'Čas strávený a odhadovaný',
    'Move position' => 'Přesuňte polohu',
    'Move task to another position on the board' => 'Přesuňte úkol na jiné místo na tabuli',
    'Insert before this task' => 'Vložit před tento úkol',
    'Insert after this task' => 'Vložit po tomto úkolu',
    'Unlock this user' => 'Odemknout tohoto uživatele',
    'Custom Project Roles' => 'Role vlastního projektu',
    'Add a new custom role' => 'Přidat novou vlastní roli',
    'Restrictions for the role "%s"' => 'Omezení role "%s"',
    'Add a new project restriction' => 'Přidat nové omezení projektu',
    'Add a new drag and drop restriction' => 'Přidat nové omezení přetažení',
    'Add a new column restriction' => 'Přidat nové omezení sloupce',
    'Edit this role' => 'Upravit tuto roli',
    'Remove this role' => 'Odebrat tuto roli',
    'There is no restriction for this role.' => 'Pro tuto roli neexistuje žádné omezení.',
    'Only moving task between those columns is permitted' => 'Povoleno je pouze přesunutí úkolu mezi těmito sloupci',
    'Close a task in a specific column when not moved during a given period' => 'Pokud není úkol během určitého období přesunut, zavřete úlohu ve specifickém sloupci',
    'Edit columns' => 'Upravit sloupce',
    'The column restriction has been created successfully.' => 'Omezení sloupce bylo úspěšně vytvořeno.',
    'Unable to create this column restriction.' => 'Toto omezení sloupce nelze vytvořit.',
    'Column restriction removed successfully.' => 'Omezení sloupců bylo úspěšně odebráno.',
    'Unable to remove this restriction.' => 'Toto omezení nelze odstranit.',
    'Your custom project role has been created successfully.' => 'Vaše vlastní role projektu byla úspěšně vytvořena.',
    'Unable to create custom project role.' => 'Nelze vytvořit vlastní roli projektu.',
    'Your custom project role has been updated successfully.' => 'Vaše vlastní role projektu byla úspěšně aktualizována.',
    'Unable to update custom project role.' => 'Nelze aktualizovat vlastní roli projektu.',
    'Custom project role removed successfully.' => 'Úkol vlastního projektu byl úspěšně odebrán.',
    'Unable to remove this project role.' => 'Tuto roli projektu nelze odstranit.',
    'The project restriction has been created successfully.' => 'Omezení projektu bylo úspěšně vytvořeno.',
    'Unable to create this project restriction.' => 'Toto omezení projektu nelze vytvořit.',
    'Project restriction removed successfully.' => 'Omezení projektu bylo úspěšně odstraněno.',
    'You cannot create tasks in this column.' => 'V tomto sloupci nelze vytvářet úkoly.',
    'Task creation is permitted for this column' => 'Pro tento sloupec je povoleno vytvoření úkolu',
    'Closing or opening a task is permitted for this column' => 'Pro tento sloupec je povoleno zavření nebo otevření úkolu ',
    'Task creation is blocked for this column' => 'Vytvoření úkolu je pro tento sloupec blokováno',
    'Closing or opening a task is blocked for this column' => 'Uzavření nebo otevření úkolu je pro tento sloupec blokováno',
    'Task creation is not permitted' => 'Vytváření úkolů není povoleno',
    'Closing or opening a task is not permitted' => 'Uzavření nebo otevření úkolu není povoleno',
    'New drag and drop restriction for the role "%s"' => 'Nové omezení přetažení pro roli "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Osoby patřící do této role budou moci přesouvat úkoly pouze mezi zdrojovým a cílovým sloupcem.',
    'Remove a column restriction' => 'Odebrat omezení sloupce',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Opravdu chcete odstranit toto omezení sloupce: "%s" na "%s"?',
    'New column restriction for the role "%s"' => 'Nové omezení sloupce pro roli "%s"',
    'Rule' => 'Pravidlo',
    'Do you really want to remove this column restriction?' => 'Opravdu chcete toto omezení sloupce odstranit?',
    'Custom roles' => 'Vlastní role',
    'New custom project role' => 'Nová role vlastního projektu',
    'Edit custom project role' => 'Upravit roli vlastního projektu',
    'Remove a custom role' => 'Odebrat vlastní roli',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Opravdu chcete tuto vlastní roli odebrat: "%s"? Všichni členové této role se stanou členem projektu.',
    'There is no custom role for this project.' => 'Pro tento projekt neexistuje žádná vlastní role.',
    'New project restriction for the role "%s"' => 'Nové omezení projektu pro roli "%s"',
    'Restriction' => 'Omezení',
    'Remove a project restriction' => 'Odebrat omezení projektu',
    'Do you really want to remove this project restriction: "%s"?' => 'Opravdu chcete toto omezení projektu odstranit: "%s"?',
    'Duplicate to multiple projects' => 'Duplikovat na více projektů',
    'This field is required' => 'Toto pole je povinné',
    'Moving a task is not permitted' => 'Přesunutí úkolu není dovoleno',
    'This value must be in the range %d to %d' => 'Tato hodnota musí být v rozsahu %d až %d',
    'You are not allowed to move this task.' => 'Tento úkol nesmíte přesouvat.',
    'API User Access' => 'API Uživatelský přístup',
    'Preview' => 'Náhled',
    'Write' => 'Napsat',
    'Write your text in Markdown' => 'Napsat svůj text v Markdown',
    'No personal API access token registered.' => 'Nebyl zaregistrován žádný token přístupu pro osobní rozhraní API.',
    'Your personal API access token is "%s"' => 'Osobní token přístupu API je "%s"',
    'Remove your token' => 'Odebrat token',
    'Generate a new token' => 'Vytvořit nový token',
    'Showing %d-%d of %d' => 'Zobrazeno %d-%d z %d',
    'Outgoing Emails' => 'Odchozí e-maily',
    'Add or change currency rate' => 'Přidat nebo změnit měnový kurz',
    'Reference currency: %s' => 'Referenční měna: %s',
    'Add custom filters' => 'Přidat vlastní filtry',
    'Export' => 'Export',
    'Add link label' => 'Přidat popisek na odkaz',
    'Incompatible Plugins' => 'Nekompatibilní zásuvné moduly',
    'Compatibility' => 'Kompatibilita',
    'Permissions and ownership' => 'Oprávnění a vlastnictví',
    'Priorities' => 'Priority',
    'Close this window' => 'Zavřít toto okno',
    'Unable to upload this file.' => 'Tento soubor nelze nahrát.',
    'Import tasks' => 'Import úkolů',
    'Choose a project' => 'Vybrat projekt',
    'Profile' => 'Profil',
    'Application role' => 'Role aplikace',
    '%d invitations were sent.' => 'Bylo odesláno %d pozvánek.',
    '%d invitation was sent.' => '%d pozvání bylo odesláno.',
    'Unable to create this user.' => 'Tohoto uživatele nelze vytvořit.',
    'Kanboard Invitation' => 'Pozvánka Kanboard',
    'Visible on dashboard' => 'Viditelné na přístrojové desce',
    'Created at:' => 'Vytvořeno:',
    'Updated at:' => 'Aktualizováno dne:',
    'There is no custom filter.' => 'Neexistuje žádný vlastní filtr.',
    'New User' => 'Nový uživatel',
    'Authentication' => 'Ověřování',
    'If checked, this user will use a third-party system for authentication.' => 'Pokud je tato volba zaškrtnuta, bude tento uživatel používat pro ověřování systém třetích stran.',
    'The password is necessary only for local users.' => 'Heslo je nutné pouze pro lokální uživatele.',
    'You have been invited to register on Kanboard.' => 'Byli jste pozváni k registraci na Kanboard.',
    'Click here to join your team' => 'Klikněte sem a připojte se ke svému týmu',
    'Invite people' => 'Pozvat lidi',
    'Emails' => 'E-maily',
    'Enter one email address by line.' => 'Zadejte jednu e-mailovou adresu na řádek.',
    'Add these people to this project' => 'Přidat tyto osoby do tohoto projektu',
    'Add this person to this project' => 'Přidat tuto osobu do tohoto projektu',
    'Sign-up' => 'Přihlásit se',
    'Credentials' => 'Pověření',
    'New user' => 'Nový uživatel',
    'This username is already taken' => 'Toto uživatelské jméno je již přijato',
    'Your profile must have a valid email address.' => 'Váš profil musí mít platnou e-mailovou adresu.',
    'TRL - Turkish Lira' => 'TRL - turecká lira',
    'The project email is optional and could be used by several plugins.' => 'E-mail projektu je nepovinný a může být použit několika pluginy.',
    'The project email must be unique across all projects' => 'E-mail projektu musí být jedinečný ve všech projektech',
    'The email configuration has been disabled by the administrator.' => 'Konfigurace e-mailu byla správcem zakázána.',
    'Close this project' => 'Uzavřít tento projekt',
    'Open this project' => 'Otevřít tento projekt',
    'Close a project' => 'Uzavřít projekt',
    'Do you really want to close this project: "%s"?' => 'Opravdu chcete zavřít tento projekt: "%s"?',
    'Reopen a project' => 'Znovu otevřít projekt',
    'Do you really want to reopen this project: "%s"?' => 'Opravdu chcete tento projekt znovu otevřít: "%s"?',
    'This project is open' => 'Tento projekt je otevřen',
    'This project is closed' => 'Tento projekt je ukončen',
    'Unable to upload files, check the permissions of your data folder.' => 'Nelze nahrát soubory, zkontrolujte oprávnění ke složce dat.',
    'Another category with the same name exists in this project' => 'V tomto projektu existuje další kategorie se stejným názvem',
    'Comment sent by email successfully.' => 'Komentář byl úspěšně odeslán e-mailem.',
    'Sent by email to "%s" (%s)' => 'Odesláno e-mailem na adresu "%s" (%s)',
    'Unable to read uploaded file.' => 'Nelze číst nahraný soubor.',
    'Database uploaded successfully.' => 'Databáze byla úspěšně nahrána.',
    'Task sent by email successfully.' => 'Úkol byl úspěšně odeslán e-mailem.',
    'There is no category in this project.' => 'V tomto projektu není žádná kategorie.',
    'Send by email' => 'Poslat e-mailem',
    'Create and send a comment by email' => 'Vytvořit a odeslat komentář e-mailem',
    'Subject' => 'Předmět',
    'Upload the database' => 'Nahrát databázi',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Můžete nahrát dříve staženou databázi Sqlite (formát Gzip).',
    'Database file' => 'Databázový soubor',
    'Upload' => 'Nahrát',
    'Your project must have at least one active swimlane.' => 'Váš projekt musí mít alespoň jednu aktivní dráhu.',
    'Project: %s' => 'Projekt: %s',
    'Automatic action not found: "%s"' => 'Automatická akce nebyla nalezena: "%s"',
    '%d projects' => '%d projektů',
    '%d project' => '%d projekt',
    'There is no project.' => 'Neexistuje žádný projekt.',
    'Sort' => 'Seřadit',
    'Project ID' => 'ID projektu',
    'Project name' => 'Název projektu',
    'Public' => 'Veřejnost',
    'Personal' => 'Osobní',
    '%d tasks' => '%d úkoly',
    '%d task' => '%d úkol',
    'Task ID' => 'ID úkolu',
    'Assign automatically a color when due date is expired' => 'Pokud datum splatnosti vyprší, přiřadit automaticky barvu',
    'Total score in this column across all swimlanes' => 'Celkové skóre v tomto sloupci napříč všemi drahami',
    'HRK - Kuna' => 'HRK - Kuna',
    'ARS - Argentine Peso' => 'ARS - Argentinské Peso',
    'COP - Colombian Peso' => 'COP - Kolumbijské Peso',
    '%d groups' => '%d skupin',
    '%d group' => '%d skupina',
    'Group ID' => 'ID skupiny',
    'External ID' => 'Externí ID',
    '%d users' => '%d uživatelů',
    '%d user' => '%d uživatel',
    'Hide subtasks' => 'Skrýt dílčí úkoly',
    'Show subtasks' => 'Zobrazit dílčí úkoly',
    'Authentication Parameters' => 'Parametry ověřování',
    'API Access' => 'API Přístup',
    'No users found.' => 'Nenalezeni žádní uživatelé.',
    'User ID' => 'Uživatelské ID',
    'Notifications are activated' => 'Oznámení jsou aktivována',
    'Notifications are disabled' => 'Oznámení jsou zakázána',
    'User disabled' => 'Uživatel je zakázán',
    '%d notifications' => '%d oznámení',
    '%d notification' => '%d oznámení',
    'There is no external integration installed.' => 'Není nainstalovaná žádná externí integrace.',
    'You are not allowed to update tasks assigned to someone else.' => 'Není dovoleno aktualizovat úkoly přiřazené někomu jinému.',
    'You are not allowed to change the assignee.' => 'Není dovoleno měnit postupníka.',
    'Task suppression is not permitted' => 'Potlačení úkolů není povoleno',
    'Changing assignee is not permitted' => 'Změna postupníka není povolena',
    'Update only assigned tasks is permitted' => 'Povolené jsou pouze úkoly přiřazené aktualizací',
    'Only for tasks assigned to the current user' => 'Pouze pro úkoly přiřazené aktuálnímu uživateli',
    'My projects' => 'Moje projekty',
    'You are not a member of any project.' => 'Nejste členem žádného projektu.',
    'My subtasks' => 'Moje dílčí úkoly',
    '%d subtasks' => '%d dílčí úkoly',
    '%d subtask' => '%d dílčí úkol',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Pro úkoly přiřazené aktuálnímu uživateli je povoleno pouze přesunutí úlohy mezi těmito sloupci',
    '[DUPLICATE]' => '[KOPIE]',
    'DKK - Danish Krona' => 'DKK - dánská koruna',
    'Remove user from group' => 'Odebrat uživatele ze skupiny',
    'Assign the task to its creator' => 'Přiřadit úkol svému tvůrci',
    'This task was sent by email to "%s" with subject "%s".' => 'Tento úkol byl zaslán e-mailem na adresu "%s" s předmětem "%s".',
    'Predefined Email Subjects' => 'Předdefinované e-mailové objekty',
    'Write one subject by line.' => 'Napsat jeden předmět na řádek.',
    'Create another link' => 'Vytvořit další odkaz',
    'BRL - Brazilian Real' => 'BRL - Brazilský Real',
    'Add a new Kanboard task' => 'Přidat nový úkol Kanboard',
    'Subtask not started' => 'Dílčí úkol nebyl spuštěn',
    'Subtask currently in progress' => 'Probíhající dílčí úkol',
    'Subtask completed' => 'Dílčí úkol byl dokončen',
    'Subtask added successfully.' => 'Dílčí úkol byl úspěšně přidán.',
    '%d subtasks added successfully.' => 'Úkoly %d byly úspěšně přidány.',
    'Enter one subtask by line.' => 'Zadejte jeden dílčí úkol na řádek.',
    'Predefined Contents' => 'Předdefinovaný obsah',
    'Predefined contents' => 'Předdefinovaný obsah',
    'Predefined Task Description' => 'Popis předdefinovaného úkolu',
    'Do you really want to remove this template? "%s"' => 'Opravdu chcete tuto šablonu odstranit? "%s"',
    'Add predefined task description' => 'Přidat předdefinovaný popis úkolu',
    'Predefined Task Descriptions' => 'Předdefinované popisy úkolů',
    'Template created successfully.' => 'Šablona byla úspěšně vytvořena.',
    'Unable to create this template.' => 'Tuto šablonu nelze vytvořit.',
    'Template updated successfully.' => 'Šablona byla úspěšně aktualizována.',
    'Unable to update this template.' => 'Tuto šablonu nelze aktualizovat.',
    'Template removed successfully.' => 'Šablona byla úspěšně odebrána.',
    'Unable to remove this template.' => 'Tuto šablonu nelze odebrat.',
    'Template for the task description' => 'Šablona pro popis úkolu',
    'The start date is greater than the end date' => 'Datum zahájení je větší než datum ukončení',
    'Tags must be separated by a comma' => 'Značky musí být odděleny čárkou',
    'Only the task title is required' => 'Je vyžadován pouze název úkolu',
    'Creator Username' => 'Uživatelské jméno tvůrce',
    'Color Name' => 'Název barvy',
    'Column Name' => 'Název sloupce',
    'Swimlane Name' => 'Název dráhy',
    'Time Estimated' => 'Odhadovaný čas',
    'Time Spent' => 'Strávený čas',
    'External Link' => 'Externí odkaz',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Tato funkce umožňuje iCal feed, RSS kanál a zobrazení veřejné rady.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Zastavení časovače všech dílčích úkolů při přesunutí úkolu do jiného sloupce',
    'Subtask Title' => 'Náázev dílčí úkolu',
    'Add a subtask and activate the timer when moving a task to another column' => 'Při přesunu úlohy do jiného sloupce přidat dílčí úkol a aktivovat časovač',
    'days' => 'dnů',
    'minutes' => 'minut',
    'seconds' => 'sekundy',
    'Assign automatically a color when preset start date is reached' => 'Při dosažení přednastaveného počátečního data automaticky přiřadit barvu',
    'Move the task to another column once a predefined start date is reached' => 'Po dosažení předdefinovaného data zahájení přesunout úkol do jiného sloupce',
    'This task is now linked to the task %s with the relation "%s"' => 'Tento úkol je nyní spojen s úkolem %s s relací "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Odkaz se vztahem "%s" na úkol %s byl odstraněn',
    'Custom Filter:' => 'Vlastní filtr:',
    'Unable to find this group.' => 'Tuto skupinu nelze najít.',
    '%s moved the task #%d to the column "%s"' => '%s přesunul úkol #%d do sloupce "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s přesunul úkol #%d do pozice %d ve sloupci "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s přesunul úkol #%d do dráhy "%s"',
    '%sh spent' => '%sh strávil',
    '%sh estimated' => '%sh odhadnuto',
    'Select All' => 'Vybrat vše',
    'Unselect All' => 'Odznačit vše',
    'Apply action' => 'Použít akci',
    'Move selected tasks to another column or swimlane' => 'Přesuňte vybrané úkoly do jiného sloupce',
    'Edit tasks in bulk' => 'Úlohy lze upravovat hromadně',
    'Choose the properties that you would like to change for the selected tasks.' => 'Vyberte vlastnosti, které chcete změnit pro vybrané úkoly.',
    'Configure this project' => 'Nakonfigurovat tento projekt',
    'Start now' => 'Začněte hned',
    '%s removed a file from the task #%d' => '%s odstranil soubor z úkolu #%d',
    'Attachment removed from task #%d: %s' => 'Příloha byla odstraněna z úlohy  #%d: %s',
    'No color' => 'Bez barvy',
    'Attachment removed "%s"' => 'Příloha byla odebrána "%s"',
    '%s removed a file from the task %s' => '%s odstranil soubor z úkolu %s',
    'Move the task to another swimlane when assigned to a user' => 'Když je úkol přiřazen uživateli, přesunout úkol na jinou dráhu',
    'Destination swimlane' => 'Cílová dráha',
    'Assign a category when the task is moved to a specific swimlane' => 'Přiřadit kategorii při přesunu úkolu na určitou dráhu',
    'Move the task to another swimlane when the category is changed' => 'Při změně kategorie přesunout úkol na jinou dráhu',
    'Reorder this column by priority (ASC)' => 'Změnit pořadí tohoto sloupce podle priority (vzestupně)',
    'Reorder this column by priority (DESC)' => 'Změnit pořadí tohoto sloupce podle priority (sestupně)',
    'Reorder this column by assignee and priority (ASC)' => 'Změnit pořadí tohoto sloupce podle zadavatele a priority (vzestupně)',
    'Reorder this column by assignee and priority (DESC)' => 'Změnit pořadí tohoto sloupce podle zadavatele a priority (sestupně)',
    'Reorder this column by assignee (A-Z)' => 'Změnit pořadí tohoto sloupce podle zadavatele (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Změnit pořadí tohoto sloupce podle zadavatele (Z-A)',
    'Reorder this column by due date (ASC)' => 'Změnit pořadí tohoto sloupce podle data vypršení platnosti (vzestupně)',
    'Reorder this column by due date (DESC)' => 'Změnit pořadí tohoto sloupce podle data vypršení platnosti (sestupně)',
    // 'Reorder this column by id (ASC)' => '',
    // 'Reorder this column by id (DESC)' => '',
    '%s moved the task #%d "%s" to the project "%s"' => '%s přesunul úkol #%d "%s" do projektu "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Úkol #%d "%s" byl přesunut do projektu "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Pokud je datum vypršení platnosti menší než určitý počet dní, přesuňte úlohu do jiného sloupce',
    'Automatically update the start date when the task is moved away from a specific column' => 'Automaticky aktualizuje datum zahájení, když je úkol přesunut z určitého sloupce',
    'HTTP Client:' => 'HTTP klient:',
    'Assigned' => 'Přiřazen',
    'Task limits apply to each swimlane individually' => 'Omezení úkolů platí pro každou dráhu samostatně',
    'Column task limits apply to each swimlane individually' => 'Omezení úkolů ve sloupcích platí pro každou dráhu samostatně',
    'Column task limits are applied to each swimlane individually' => 'Omezení úkolů ve sloupcích jsou aplikovány na každou dráhu samostatně',
    'Column task limits are applied across swimlanes' => 'Omezení úkolů ve sloupcích jsou aplikovány napříč drahami',
    'Task limit: ' => 'Limit úkolu:',
    'Change to global tag' => 'Změnit na globální značku',
    'Do you really want to make the tag "%s" global?' => 'Opravdu chcete, aby se značka "%s" stala globální?',
    'Enable global tags for this project' => 'Povolit pro tento projekt globální značky',
    'Group membership(s):' => 'Členství ve skupině:',
    '%s is a member of the following group(s): %s' => '%s je členem následující skupiny (skupin): %s',
    '%d/%d group(s) shown' => 'zobrazeno(a) %d/%d skupin(a)',
    'Subtask creation or modification' => 'Vytvoření nebo úprava dílčího úkolu',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Přiřadit úkol určitému uživateli při přesunu úkolu na určitou dráhu',
    'Comment' => 'Komentář',
    'Collapse vertically' => 'Rozbalit svisle',
    'Expand vertically' => 'Sbalit svisle',
    // 'MXN - Mexican Peso' => '',
    // 'Estimated vs actual time per column' => '',
    // 'HUF - Hungarian Forint' => '',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    // 'You must select a file to upload as your avatar!' => '',
    // 'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '',
    // 'Automatically set the due date when the task is moved away from a specific column' => '',
    // 'No other projects found.' => '',
    // 'Please choose a project you want to copy the tasks from.' => '',
    // 'Import Tasks' => '',
    // 'Copy' => '',
    // 'Tasks copied successfully.' => '',
    // 'Unable to copy tasks.' => '',
    // 'Theme' => '',
    // 'Theme:' => '',
    // 'Light theme' => '',
    // 'Dark theme' => '',
    // 'Automatic theme - Sync with system' => '',
    // 'Application managers or more' => '',
    // 'Administrators' => '',
    // 'Visibility:' => '',
    // 'Standard users' => '',
    // 'Visibility is required' => '',
    // 'The visibility should be an app role' => '',
    // 'Reply' => '',
    // '%s wrote: ' => '',
    // 'Number of visible tasks in this column and swimlane' => '',
    // 'Number of tasks in this swimlane' => '',
    // 'Unable to find another subtask in progress, you can close this window.' => '',
    // 'This theme is invalid' => '',
    // 'This role is invalid' => '',
    // 'This timezone is invalid' => '',
    // 'This language is invalid' => '',
    // 'This URL is invalid' => '',
    // 'Date format invalid' => '',
    // 'Time format invalid' => '',
    // 'Invalid Mail transport' => '',
    // 'Color invalid' => '',
    // 'This value must be greater or equal to %d' => '',
    // 'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '',
    // 'Just add these tag(s)' => '',
    // 'Remove internal link(s)' => '',
);
